@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use stdClass;
@@ -12,7 +14,7 @@ use Webmozart\Assert\Assert;
  *
  * @return non-empty-array<string, mixed>
  */
-function isNonEmptyMap($value): array
+function isNonEmptyMap(mixed $value): array
 {
     Assert::isNonEmptyMap($value);
 
@@ -39,10 +41,8 @@ function isNonEmptyMapWithKnownType(array $value): array
  * @psalm-pure
  *
  * @param mixed $value
- *
- * @return mixed
  */
-function nullOrIsNonEmptyMap($value)
+function nullOrIsNonEmptyMap(mixed $value): mixed
 {
     Assert::nullOrIsNonEmptyMap($value);
 
@@ -53,8 +53,6 @@ function nullOrIsNonEmptyMap($value)
  * @psalm-pure
  *
  * @param iterable<mixed|array<mixed>> $value
- *
- * @return iterable<mixed|array<mixed>>
  */
 function allIsNonEmptyMap(iterable $value): iterable
 {
@@ -67,8 +65,6 @@ function allIsNonEmptyMap(iterable $value): iterable
  * @psalm-pure
  *
  * @param iterable<mixed|array<mixed>> $value
- *
- * @return iterable<mixed|array<mixed>>
  */
 function allNullOrIsNonEmptyMap(iterable $value): iterable
 {
